@@ -1,5 +1,5 @@
-## -----------------------------------------------------------------------------
-library("lessR")
+## ----include=FALSE------------------------------------------------------------
+suppressPackageStartupMessages(library("lessR"))
 
 ## ----read---------------------------------------------------------------------
 d <- Read("Employee")
