@@ -1,5 +1,5 @@
 ## ----include=FALSE----------------------------------------------------------------------------------------------------
-library("lessR")
+suppressPackageStartupMessages(library("lessR"))
 
 ## ---------------------------------------------------------------------------------------------------------------------
 d <- Read("Employee")
